# REES46

Гем для отправки событий и приема рекомедаций

## Установка

```
gem 'rees46'
```
```
bundle
```

## Инициализация

В первую очередь необходимо инициализировать модуль:
```ruby
REES46.configure do |config|
  config.shop_id = "КОД_ВАШЕГО_МАГАЗИНА"
  config.user_id = "ID_ТЕКУЩЕГО_ПОЛЬЗОВАТЕЛЯ"
  config.session_id = "ID_СЕССИИ_ТЕКУЩЕГО_ПОЛЬЗОВАТЕЛЯ"
end
```

```shop_id``` - обязательный параметр

После процесса инициализации необходимо связать пользователя (в том числе анонимного) со сгенерированным ID сессии (например, сохранить в локальное хранилище приложения), а затем передавать его в конфигурацию при последующем использовании:

```
ваш_метод_сохранения_id_сессии(REES46.config.session_id)
```

## Отслеживание событий

Все действия необходимо производить только после инициализации модуля.

[Список параметров](http://memo.mkechinov.ru/pages/viewpage.action?pageId=786532#id-ИспользованиеJSSDK-4.1.СтруктураPARAMS(информацияособытии)), которые можно передавать с товаром. Чем больше будет передано параметров - тем выше будет качество рекомендаций.

### Просмотр:
```ruby
REES46::Tracker.view(item: { item_id: 5, price: 1499.99, is_available: true })
```

### Добавление в корзину
```ruby
REES46::Tracker.cart(item: { item_id: 5, price: 1499.99, is_available: true })
```

### Удаление из корзины
```ruby
REES46::Tracker.remove_from_cart(item: { item_id: 5, price: 1499.99, is_available: true })
```

### Покупка
```ruby
REES46::Tracker.purchase(items: [{ item_id: 5, price: 1499.99, is_available: true, amount: 1 }, { item_id: 1, price: 50, is_available: true, amount: 5}], order_id: 25)
```

### Оценка
```ruby
REES46::Tracker.rate(item: { item_id: 5, price: 1499.99, is_available: true }, rating: 5)
```

## Запрос рекомендаций

Все действия необходимо производить только после инициализации модуля.
Запросы возвращают массив ID товаров.

Все рекомендеры принимают опциональные параметры:
```item``` - означает текущий просматриваемый товар.

```cart``` - означает текущее содержимое корзины.

Лучше всего их передавать всегда, это повысит качество рекомендаций.


### Вас это заинтересует
```ruby
REES46::Recommender.interesting(item: 4291, cart: [2,5,6])
```

### Популярные
```ruby
REES46::Recommender.popular(category: 256)
```
Здесь передается ID просматриваемой категории. Если не передать этот параметр - будут рекомендации по всем категориям.


### С этим товаром покупают
```ruby
REES46::Recommender.also_bought(item: 23)
```
В данном случае item - обязательный параметр.

### Посмотрите также
```ruby
REES46::Recommender.see_also(cart: [5, 23])
```
В данном случае cart - обязательный параметр.

### Вы недавно смотрели
```ruby
REES46::Recommender.recently_viewed
```
Не требует дополнительных параметров

### Прямо сейчас покупают
```ruby
REES46::Recommender.buying_now
```

[Дополнительная информация](http://rees46.com/integration)
