require 'spec_helper'
require 'rees46'

describe REES46::Tracker do
  it 'has an array constant of event types' do
    expect(REES46::Tracker::EVENT_TYPES).to be_an(Array)
  end

  it 'has a method shortcut for each event type' do
    REES46::Tracker::EVENT_TYPES.each do |event_type|
      expect(REES46::Tracker).to respond_to(event_type)
    end
  end

  it 'has an array if all possible item attibutes' do
    expect(REES46::Tracker::ITEM_ATTRIBUTES).to be_an(Array)
  end

  describe '.track' do
    it 'raises error if module is not configured' do
      expect {
        REES46::Tracker.track(:view, {})
      }.to raise_error(REES46::NotConfiguredError)
    end
  end

  context 'events' do
    before do
      REES46.configure do |config|
        config.shop_id = test_shop_id
        config.user_id = test_user_id
        config.session_id = test_session_id
      end
    end

    describe '.view' do
      it 'sends request' do
        REES46::Tracker.view(item: { item_id: 1, price: 1500.25, available: true, category: 15 })
      end
    end

    describe '.cart' do
      it 'sends request' do
        REES46::Tracker.cart(item: { item_id: 1, price: 1500.25, available: true, category: 15 })
      end
    end

    describe '.remove_from_cart' do
      it 'sends request' do
        REES46::Tracker.remove_from_cart(item: { item_id: 1, price: 1500.25, available: true, category: 15 })
      end
    end

    describe '.purchase' do
      it 'sends request' do
        items_info = [
          {
            item_id: 1,
            price: 1500,
            available: true,
            category: 15,
            amount: 5
          },
          {
            item_id: 2,
            price: 300,
            available: true,
            category: 2,
            amount: 1
          }
        ]

        REES46::Tracker.purchase(items: items_info, order_id: 25)
      end
    end
  end
end
